<?php

namespace Beau\Card\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Beau\Card\Interfaces\CardRepositoryInterface;
use Beau\Card\Repositories\Presenter\CardItemTransformer;

/**
 * Pubic API controller class.
 */
class CardApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Beau\Card\Interfaces\CardRepositoryInterface $card
     *
     * @return type
     */
    public function __construct(CardRepositoryInterface $card)
    {
        $this->middleware('api');

        $this->repository = $card;
        parent::__construct();
    }

    /**
     * Show card's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $cards = $this->repository
            ->pushCriteria(new \Beau\Card\Repositories\Criteria\CardPublicCriteria())
            ->setPresenter('\\Beau\\Card\\Repositories\\Presenter\\CardListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $cards['code'] = 2000;
        return response()->json($cards)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show card.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $card = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($card)) {
            $card         = $this->itemPresenter($module, new CardItemTransformer);
            $card['code'] = 2001;
            return response()->json($card)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
