<?php

namespace Beau\Card\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Beau\Card\Models\Card;

class CardPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the card.
     *
     * @param User $user
     * @param Card $card
     *
     * @return bool
     */
    public function view(User $user, Card $card)
    {
        if ($user->canDo('card.card.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $card->user_id;
    }

    /**
     * Determine if the given user can create a card.
     *
     * @param User $user
     * @param Card $card
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('card.card.create');
    }

    /**
     * Determine if the given user can update the given card.
     *
     * @param User $user
     * @param Card $card
     *
     * @return bool
     */
    public function update(User $user, Card $card)
    {
        if ($user->canDo('card.card.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $card->user_id;
    }

    /**
     * Determine if the given user can delete the given card.
     *
     * @param User $user
     * @param Card $card
     *
     * @return bool
     */
    public function destroy(User $user, Card $card)
    {
        if ($user->canDo('card.card.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $card->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
